==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/experiments/dialogs_it.lua <==

dialogId("bank-m-labolator1", "font_small", "This must be some kind of laboratory.")
dialogStr("Questo dev'essere una sorta di laboratorio.")

dialogId("bank-m-labolator2", "font_small", "It seems that even UFOs can be equipped with an on-board lab.")
dialogStr("Sembrerebbe che anche gli UFO siano dotati di laboratori a bordo.")

dialogId("bank-m-labolator3", "font_small", "This looks like a laboratory.")
dialogStr("Sembra un laboratorio.")

dialogId("bank-v-pokusy1", "font_big", "These experiments seem quite suspicious to me.")
dialogStr("Questi esperimenti sono piuttosto sospetti, per me.")

dialogId("bank-v-pokusy2", "font_big", "I think that someone`s carrying out some rather suspicious experiments here.")
dialogStr("Penso che qualcuno stia portando avanti degli esperimenti sospetti, qui.")

dialogId("bank-m-jejda", "font_small", "My gosh, what`s this?!?")
dialogStr("Oddio, cos'è questo?!?")

dialogId("bank-v-zije", "font_big", "Everything`s alive here.")
dialogStr("Qui dentro si muove tutto.")

dialogId("bank-m-nerus", "font_small", "Shhhhh, I need to examine this laboratory.")
dialogStr("Silenzio, devo esaminare questo laboratorio.")

dialogId("bank-m-bojim", "font_small", "I`m little bit afraid of that thing behind the door...")
dialogStr("Sono spaventata da quella cosa dietro la porta...")

dialogId("bank-m-ocicka", "font_small", "Why does it have three eyes?")
dialogStr("Perché ha tre occhi?")

dialogId("bank-v-pomoc", "font_big", "Stop what you`re doing down there and come help me!")
dialogStr("Smettila di perdere tempo laggiù e vieni ad aiutarmi!")

dialogId("bank-m-organismy", "font_small", "I would never have thought that we`d find so many living things inside a UFO...")
dialogStr("Non avrei mai pensato di trovare così tanti esseri viventi in un UFO...")

dialogId("bank-v-potvory", "font_big", "There are an incredible number of different creatures here!")
dialogStr("C'è un'incredibile varietà di creature, qui!")

dialogId("bank-v-mnozeni", "font_big", "My goodness, look at those things reproduce!")
dialogStr("O mio dio, guarda quelle cose riprodursi!")

dialogId("bank-m-nesetkala", "font_small", "I`ve never seen this kind of organism before.")
dialogStr("Non ho mai visto questo tipo di organismo prima d'ora.")

dialogId("bank-m-kouka", "font_small", "Help! It`s looking at me!")
dialogStr("Aiuto! mi sta guardando!")

dialogId("bank-m-fuj", "font_small", "Yuck.")
dialogStr("Bleah.")

dialogId("bank-m-nervozni", "font_small", "That hand gives me the creeps...")
dialogStr("Quella mano mi fa rabbrividire...")

dialogId("bank-m-zkumavka", "font_small", "There`s a strange odor coming from this test-tube...")
dialogStr("Da questa provetta si sente provenire uno strano odore...")

dialogId("bank-m-hlavakolem", "font_small", "All of this is making my head spin...")
dialogStr("Tutto questo mi fa girare la testa...")

dialogId("bank-v-neproplavu1", "font_big", "I can`t swim through here. We`re going to have to push this aside.")
dialogStr("Non riesco a nuotarci in mezzo, dovremo spostarlo più in là.")

dialogId("bank-v-neproplavu2", "font_big", "I can`t swim through here. We`re going to have to push this down.")
dialogStr("Non riesco a nuotarci in mezzo, dovremo tirarlo giù.")

dialogId("bank-v-nahazet", "font_big", "We`re going to need to throw on a lot more of these things.")
dialogStr("Dovremo aver bisogno di gettar via ancora molte di queste cose.")

dialogId("bank-v-jeste", "font_big", "More.")
dialogStr("Ancora.")

dialogId("bank-m-prohlednout", "font_small", "We have to look everything here over very carefully.")
dialogStr("Dobbiamo osservare tutto quello che è qui molto attentamente.")

dialogId("bank-v-vypad1", "font_big", "I`d rather get out of here.")
dialogStr("Io piuttosto me ne andrei.")

dialogId("bank-v-vypad2", "font_big", "You know, I`d really rather get out of here.")
dialogStr("Vedi, piuttosto io me ne andrei.")

dialogId("bank-v-flaska", "font_big", "The odor from this bottle is making me sick.")
dialogStr("L'odore di questa bottiglia mi fa sentir male.")

dialogId("bank-m-rozbila", "font_small", "Ooops, it broke...")
dialogStr("Ooops, si è rotto...")

dialogId("bank-m-tvorove", "font_small", "I think that some of these creatures here are a result of genetic engineering.")
dialogStr("Penso che alcune di queste creature qui siano il risultato di manipolazioni genetiche.")

dialogId("bank-m-prehnal1", "font_small", "This is just too much!")
dialogStr("Questo è semplicemente troppo!")

dialogId("bank-m-prehnal2", "font_small", "How morbid!")
dialogStr("Che morbido!")

dialogId("bank-m-mrtvolka", "font_small", "This corpse looks familiar to me.")
dialogStr("Questa salma mi sembra familiare.")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/experiments/dialogs_it.lua <==

dialogId("bank-m-labolator1", "font_small", "This must be some kind of laboratory.")
dialogStr("Questo dev'essere una sorta di laboratorio.")

dialogId("bank-m-labolator2", "font_small", "It seems that even UFOs can be equipped with an on-board lab.")
dialogStr("Sembrerebbe che anche gli UFO siano dotati di laboratori a bordo.")

dialogId("bank-m-labolator3", "font_small", "This looks like a laboratory.")
dialogStr("Sembra un laboratorio.")

dialogId("bank-v-pokusy1", "font_big", "These experiments seem quite suspicious to me.")
dialogStr("Questi esperimenti sono piuttosto sospetti, per me.")

dialogId("bank-v-pokusy2", "font_big", "I think that someone’s carrying out some rather suspicious experiments here.")
dialogStr("Penso che qualcuno stia portando avanti degli esperimenti sospetti, qui.")

dialogId("bank-m-jejda", "font_small", "My gosh, what’s this?!?")
dialogStr("Oddio, cos'è questo?!?")

dialogId("bank-v-zije", "font_big", "Everything’s alive here.")
dialogStr("Qui dentro si muove tutto.")

dialogId("bank-m-nerus", "font_small", "Shhhhh, I need to examine this laboratory.")
dialogStr("Silenzio, devo esaminare questo laboratorio.")

dialogId("bank-m-bojim", "font_small", "I’m little bit afraid of that thing behind the door...")
dialogStr("Sono spaventata da quella cosa dietro la porta...")

dialogId("bank-m-ocicka", "font_small", "Why does it have three eyes?")
dialogStr("Perché ha tre occhi?")

dialogId("bank-v-pomoc", "font_big", "Stop what you’re doing down there and come help me!")
dialogStr("Smettila di perdere tempo laggiù e vieni ad aiutarmi!")

dialogId("bank-m-organismy", "font_small", "I would never have thought that we’d find so many living things inside a UFO...")
dialogStr("Non avrei mai pensato di trovare così tanti esseri viventi in un UFO...")

dialogId("bank-v-potvory", "font_big", "There are an incredible number of different creatures here!")
dialogStr("C'è un'incredibile varietà di creature, qui!")

dialogId("bank-v-mnozeni", "font_big", "My goodness, look at those things reproduce!")
dialogStr("O mio dio, guarda quelle cose riprodursi!")

dialogId("bank-m-nesetkala", "font_small", "I’ve never seen this kind of organism before.")
dialogStr("Non ho mai visto questo tipo di organismo prima d'ora.")

dialogId("bank-m-kouka", "font_small", "Help! It’s looking at me!")
dialogStr("Aiuto! mi sta guardando!")

dialogId("bank-m-fuj", "font_small", "Yuck.")
dialogStr("Bleah.")

dialogId("bank-m-nervozni", "font_small", "That hand gives me the creeps...")
dialogStr("Quella mano mi fa rabbrividire...")

dialogId("bank-m-zkumavka", "font_small", "There’s a strange odor coming from this test-tube...")
dialogStr("Da questa provetta si sente provenire uno strano odore...")

dialogId("bank-m-hlavakolem", "font_small", "All of this is making my head spin...")
dialogStr("Tutto questo mi fa girare la testa...")

dialogId("bank-v-neproplavu1", "font_big", "I can’t swim through here. We’re going to have to push this aside.")
dialogStr("Non riesco a nuotarci in mezzo, dovremo spostarlo più in là.")

dialogId("bank-v-neproplavu2", "font_big", "I can’t swim through here. We’re going to have to push this down.")
dialogStr("Non riesco a nuotarci in mezzo, dovremo tirarlo giù.")

dialogId("bank-v-nahazet", "font_big", "We’re going to need to throw on a lot more of these things.")
dialogStr("Dovremo aver bisogno di gettar via ancora molte di queste cose.")

dialogId("bank-v-jeste", "font_big", "More.")
dialogStr("Ancora.")

dialogId("bank-m-prohlednout", "font_small", "We have to look everything here over very carefully.")
dialogStr("Dobbiamo osservare tutto quello che è qui molto attentamente.")

dialogId("bank-v-vypad1", "font_big", "I’d rather get out of here.")
dialogStr("Io piuttosto me ne andrei.")

dialogId("bank-v-vypad2", "font_big", "You know, I’d really rather get out of here.")
dialogStr("Vedi, piuttosto io me ne andrei.")

dialogId("bank-v-flaska", "font_big", "The odor from this bottle is making me sick.")
dialogStr("L'odore di questa bottiglia mi fa sentir male.")

dialogId("bank-m-rozbila", "font_small", "Ooops, it broke...")
dialogStr("Ooops, si è rotto...")

dialogId("bank-m-tvorove", "font_small", "I think that some of these creatures here are a result of genetic engineering.")
dialogStr("Penso che alcune di queste creature qui siano il risultato di manipolazioni genetiche.")

dialogId("bank-m-prehnal1", "font_small", "This is just too much!")
dialogStr("Questo è semplicemente troppo!")

dialogId("bank-m-prehnal2", "font_small", "How morbid!")
dialogStr("Che morbido!")

dialogId("bank-m-mrtvolka", "font_small", "This corpse looks familiar to me.")
dialogStr("Questa salma mi sembra familiare.")
